Raven.js
========

Raven.js is a tiny standalone JavaScript client for `Sentry <http://www.getsentry.com/>`_.

**This version of Raven.js requires Sentry 6.0 or newer.**


Getting Started
---------------

.. toctree::
   :maxdepth: 2

   install/index
   plugins/index
   config/index
   usage/index
   tips/index

Developers
----------
.. toctree::
   :maxdepth: 2

   contributing/index

What's New?
-----------
.. toctree::
   :maxdepth: 2

   changelog/index

Resources
---------
* `Download <http://ravenjs.com>`_
* `Bug Tracker <https://github.com/getsentry/raven-js/issues>`_
* `Code <https://github.com/getsentry/raven-js>`_
* `IRC <irc://irc.freenode.net/sentry>`_ (irc.freenode.net, #sentry)
* :doc:`Changelog </changelog/index>`
* Follow `@mattrobenolt <https://twitter.com/mattrobenolt>`_ on Twitter for updates!
